@@ -1,6 +1,3 @@
-"""
-Simple test case to check that the platform-specific entry scripts (gitsum and gitsum.bat) are working.
-"""
 from inspect import cleandoc
 
 from test.base_test_case import TestCase
@@ -9,7 +6,7 @@ from test.base_test_case import TestCase
 class HelpTests(TestCase):
     def test_help(self):
         expected = cleandoc(f"""
-            usage: gitsum [-h] [-f] [-o] [-O]
+            usage: gitsum [-h] [-f] [-o] [-O] [-V]
 
             View a summary of statuses for multiple Git repositories.
 
@@ -20,7 +17,8 @@ class HelpTests(TestCase):
                                     repository
               -O, --only-outside-files
                                     list files and directories that are not inside a Git
-                                    repository and exit"""
-        )
-        actual = self.run_gitsum(["--help"], shell=True)
+                                    repository and exit
+              -V, --version         display the version number and exit
+        """)
+        actual = self.run_gitsum(["--help"])
         self.assert_lines_equal(expected, actual, regex=True)
